=== modified file 'loggerhead/apps/filesystem.py'
--- loggerhead/apps/filesystem.py	2008-08-01 21:04:29 +0000
+++ loggerhead/apps/filesystem.py	2008-08-01 04:18:27 +0000
@@ -1,20 +1,40 @@
 """Serve branches at urls that mimic the file system layout."""
 
+import cgi
 import os
 import tempfile
 
 from bzrlib import branch, errors, lru_cache
 
 from paste.request import path_info_pop
+from paste.wsgiwrappers import WSGIRequest, WSGIResponse
 from paste import httpexceptions
 
 from loggerhead.apps.branch import BranchWSGIApp
 from loggerhead.apps import favicon_app, static_app
-from loggerhead.controllers.directory_ui import DirectoryUI
 
 sql_dir = tempfile.mkdtemp(prefix='loggerhead-cache-')
 
 
+class DirectoryListing(object):
+
+    def __init__(self, path):
+        self.path = path
+
+    def __call__(self, environ, start_response):
+        request = WSGIRequest(environ)
+        response = WSGIResponse()
+        listing = [d for d in os.listdir(self.path) if not d.startswith('.')]
+        response.headers['Content-Type'] = 'text/html'
+        print >> response, '<html><body>'
+        for d in sorted(listing):
+            if os.path.isdir(os.path.join(self.path, d)):
+                d = cgi.escape(d)
+                print >> response, '<li><a href="%s/">%s</a></li>' % (d, d)
+        print >> response, '</body></html>'
+        return response(environ, start_response)
+
+
 class BranchesFromFileSystemServer(object):
     def __init__(self, path, root, name=None):
         self.path = path
@@ -36,11 +56,7 @@
             raise httpexceptions.HTTPMovedPermanently(
                 environ['SCRIPT_NAME'] + '/')
         elif segment == '':
-            if self.name:
-                name = self.name
-            else:
-                name = os.path.basename(os.path.abspath(self.path))
-            return DirectoryUI(environ['loggerhead.static.url'], self.path, name)
+            return DirectoryListing(self.path)
         else:
             new_path = os.path.join(self.path, segment)
             if self.name:

=== removed file 'loggerhead/controllers/directory_ui.py'
--- loggerhead/controllers/directory_ui.py	2008-08-04 21:22:16 +0000
+++ loggerhead/controllers/directory_ui.py	1970-01-01 00:00:00 +0000
@@ -1,73 +0,0 @@
-# Copyright (C) 2008  Canonical Ltd.
-#                     (Authored by Martin Albisetti <argentina@gmail.com>)
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
-
-import datetime
-import logging
-import os
-
-from bzrlib import branch
-
-from loggerhead.controllers import TemplatedBranchView
-
-class DirEntry(object):
-    def __init__(self, dirname, parity, branch):
-        self.dirname = dirname
-        self.parity = parity
-        self.branch = branch
-        if branch is not None:
-            self.last_change =  datetime.datetime.fromtimestamp(
-                branch.repository.get_revision(branch.last_revision()).timestamp)
-
-class DirectoryUI(TemplatedBranchView):
-    """
-    """
-
-    template_path = 'loggerhead.templates.directory'
-
-    def __init__(self, static_url_base, path, name):
-        class _branch(object):
-            context_url = 1
-        self._branch = _branch
-        self._history = None
-        self._path = path
-        self._name = name
-        self._static_url_base = static_url_base
-        self.log = logging.getLogger('')
-
-    def get_values(self, h, args, kwargs, response):
-        listing = [d for d in os.listdir(self._path)
-                   if not d.startswith('.')
-                   and os.path.isdir(os.path.join(self._path, d))]
-        listing.sort(key=lambda x: x.lower())
-        dirs = []
-        parity = 0
-        def static_url(path):
-            return self._static_url_base + path
-        for d in listing:
-            p = os.path.join(self._path, d)
-            try:
-                b = branch.Branch.open(p)
-            except:
-                b = None
-            dirs.append(DirEntry(d, parity, b))
-            parity = 1 - parity
-        return {
-            'dirs': dirs,
-            'name': self._name,
-            'static_url': static_url,
-            }

=== removed file 'loggerhead/static/images/ico_branch.gif'
Binary files loggerhead/static/images/ico_branch.gif and loggerhead/static/images/ico_branch.gif differ
=== removed file 'loggerhead/templates/directory.pt'
--- loggerhead/templates/directory.pt	2008-08-04 21:55:02 +0000
+++ loggerhead/templates/directory.pt	1970-01-01 00:00:00 +0000
@@ -1,53 +0,0 @@
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
-<html xmlns="http://www.w3.org/1999/xhtml" >
-  <head>
-    <title tal:content="string:Browsing ${name}"></title>
-    <link rel="stylesheet"
-          tal:attributes="href python:static_url('/static/css/global.css')" />
-  </head>
-  <body>
-    <div id="loggerheadCont">
-      <h1 tal:content="string:Browsing ${name}">
-        Hi.
-      </h1>
-
-      <div >
-        <table id="logentries">
-          <tr class="logheader">
-            <th class="summarycell">Filename</th>
-            <th class="datecell">Latest Rev</th>
-            <th class="datecell">Last Changed</th>
-          </tr>
-          
-          <tal:block repeat="dir dirs">
-            <tal:branch-row tal:condition="dir/branch">
-              <tr tal:attributes="class string:blueRow${dir/parity}">
-                <td class="autcell">
-                  <img tal:attributes="src python:static_url('/static/images/ico_branch.gif')" />
-                  <a tal:attributes="href string:${dir/dirname}/files" tal:content="dir/dirname" /></td>
-                <td class="date">
-                  <a tal:attributes="href string:${dir/dirname}/revision/${dir/branch/revno};
-                                     title string:Show revision ${dir/branch/revno}"
-                     tal:content="dir/branch/revno"></a>
-                </td>
-                <td class="date" tal:content="python:util.date_time(dir.last_change)"></td>
-              </tr>
-            </tal:branch-row>
-            <tal:non-branch-row tal:condition="not:dir/branch">
-              <tr tal:attributes="class string:blueRow${dir/parity}">
-                <td class="autcell">
-                  <img tal:attributes="src python:static_url('/static/images/ico_folder.gif')" />
-                  <a tal:attributes="href string:${dir/dirname}" tal:content="dir/dirname" /></td>
-                <td class="date">
-                </td>
-                <td class="date" tal:content="dir/last_change">
-                  FIXME: changed date here!
-                </td>
-              </tr>
-            </tal:non-branch-row>
-          </tal:block>
-        </table>
-      </div>
-    </div>
-  </body>
-</html>

=== modified file 'serve-branches'
--- serve-branches	2008-08-01 04:42:14 +0000
+++ serve-branches	2008-07-26 17:41:49 +0000
@@ -16,81 +16,36 @@
 """Search for branches underneath a directory and serve them all."""
 
 import logging
-import os
 import sys
 
-from optparse import OptionParser
-
 from paste import httpserver
 from paste.httpexceptions import HTTPExceptionHandler
 from paste.translogger import TransLogger
 
-from loggerhead import __version__
-from loggerhead.apps.filesystem import (
-    BranchesFromFileSystemRoot, UserBranchesFromFileSystemRoot)
-
-
-def command_line_parser():
-    parser = OptionParser("%prog [options] <path>")
-    parser.set_defaults(
-        user_dirs=False,
-        show_version=False,
-        )
-    parser.add_option("--user-dirs", action="store_true", dest="user_dirs",
-                      help="Serve user directories as ~user.")
-    parser.add_option("--trunk-dir", metavar="DIR",
-                      help="The directory that contains the trunk branches.")
-    parser.add_option("--version", action="store_true", dest="show_version",
-                      help="Print the software version and exit")
-    return parser
-
-
-def main(args):
-    logging.basicConfig()
-    logging.getLogger().setLevel(logging.DEBUG)
-
-    parser = command_line_parser()
-    (options, args) = parser.parse_args(sys.argv[1:])
-
-    if options.show_version:
-        print "loggerhead %s" % __version__
-        sys.exit(0)
-
-    if len(args) > 1:
-        parser.print_help()
-        sys.exit(1)
-    elif len(args) == 1:
-        [path] = args
-    else:
-        path = '.'
-
-    if not os.path.isdir(path):
-        print "%s is not a directory" % path
-        sys.exit(1)
-
-    if options.trunk_dir and not options.user_dirs:
-        print "--trunk-dir is only valid with --user-dirs"
-        sys.exit(1)
-
-    if options.user_dirs:
-        if not options.trunk_dir:
-            print "You didn't specify a directory for the trunk directories."
-            sys.exit(1)
-        app = UserBranchesFromFileSystemRoot(path, options.trunk_dir)
-    else:
-        app = BranchesFromFileSystemRoot(path)
-    app = HTTPExceptionHandler(app)
-    app = TransLogger(app)
-
-    try:
-        from paste.deploy.config import PrefixMiddleware
-    except ImportError:
-        pass
-    else:
-        app = PrefixMiddleware(app)
-
-    httpserver.serve(app, host='0.0.0.0', port='8080')
-
-
-if __name__ == "__main__":
-    main(sys.argv)
+from loggerhead.apps.filesystem import BranchesFromFileSystemRoot
+
+
+logging.basicConfig()
+logging.getLogger().setLevel(logging.DEBUG)
+
+if len(sys.argv) > 1:
+    path = sys.argv[1]
+else:
+    path = '.'
+
+app = BranchesFromFileSystemRoot(path)
+
+app = HTTPExceptionHandler(app)
+app = TransLogger(app)
+
+try:
+    from paste.deploy.config import PrefixMiddleware
+except ImportError:
+    pass
+else:
+    app = PrefixMiddleware(app)
+
+#from paste.evalexception import EvalException
+#app = EvalException(app)
+
+httpserver.serve(app, host='0.0.0.0', port='8080')

